@@ -16,9 +16,8 @@ import time
 
 def df_retainCols(dfdata, collist): #deletes columns in df which are not there in list of columns
     # collist (a list) should contain the list of columns to be retained
-    dfdata1 = dfdata
-    dfdata1.drop(columns=[col for col in dfdata1 if col not in collist], inplace=True)
-    return dfdata1
+    dfdata.drop(columns=[col for col in dfdata if col not in collist], inplace=True)
+    return dfdata
 
 def df_delCcols(dfdata, collist): #deletes columns in df which are there in list of columns
     # collist (a list) should contain the list of columns to be deleted
@@ -187,6 +186,7 @@ def convertpath(fpath):
     return fpath
 
 def get_file_details(file_path):
+    '''Gets file details for the given file. Created time, modified time, size in MB'''
 
     try:
         # creation date and time
@@ -215,10 +215,10 @@ def get_file_details(file_path):
         mtstr = None
         sz = None
 
-    return [[ct,ctstr],[mt,mtstr],sz]
+    return [ct,mt,sz]
 
-def get_full_file_list_df(dirName):
-    # gets full file and directory tree under given directory
+def get_full_file_list_df(dirName:str)->pd.DataFrame:
+    ''' gets full file and directory tree under given directory '''
 
     dir_list = []
     dir_list.append(dirName)
@@ -251,6 +251,7 @@ def read_from_csv(filePath):
         dataList.append(row)
     inFile.close()
     return dataList
+
 class date_converter:
     #takes string in dd/mm/yyyy or dd/mm/yy format, checks data validity and converts into
     # proper date in final_date attribute
